#!/bin/bash

function die {
  echo "ERROR: $@"
  exit 1
}

function check_file {
  [[ -f "$1" ]] || die "FILE '$1' not found"
}

XML=2.1.xml
DTD=3.3.dtd

check_file "$XML"
check_file "$DTD"

xmllint --version 2> /dev/null || die "xmllint not found. Please install it."
xsltproc --version > /dev/null || die "xsltproc not found. Please install it."

xmllint --noout "$XML" || die "File '$FILE' is not a valid XML file."
echo "Test 0 PASSED: '$XML' is a valid XML file."

xmllint --noout --dtdvalid "$DTD" "$XML" \
  || die "Invalid DTD '$DTD' or File '$XML' does not correspond to it."
echo "Test 1 PASSED: '$XML' corresponds to DTD '$DTD'."

for i in 3.3.*.xsl; do
  xsltproc $i "$XML" > tmp.xml && xmllint --noout tmp.xml || die "Couldn't process test '$i'"
  xmllint --noout --dtdvalid "$DTD" tmp.xml && die "DTD does not pass strictness test '$i'"
  echo "Strictness test '$i' PASSED"
done
rm tmp.xml

echo "SUCCESS"
