#!/bin/bash

function die {
  echo -e "ERROR: $@"
 exit 1
}

function check_files {
  local i
  for i in $@; do
    [[ -f "$i" ]] || die "File not found: '$i'"
  done
}

function check_eq {
  [[ "$1" = "$2" ]] || die "Expected: '$1'\nand got instead: '$2'"
}

[[ "$#" = 1 ]] && [[ -f "$1" ]] && tar tf "$1" > /dev/null 2>&1 || die "Usage: $0 archive.tar"

TMP=tmp
mkdir $TMP
cd $TMP

TD="$1"
[[ "${TD:0:1}" != "/" ]] && TD="../$TD"
tar xf "$TD" --wildcards *.cc *.h *.txt Makefile

# Args: $1 = command to execute
#       $2 = partial credit keyword (eg. "PASSED")
#       $3 = score table: 3 characters per score. Eg. "  0  0  2  2  4" to support scores 0..4.
#            The score will be taken from the table, at an index that corresponds to
#            the number of keywords ($2) found in the command output.
function grade {
  [[ "$#" = 3 ]] || die "Example usage: grade command keyword 'score table'"
  local OUT="$($1)"
  echo "$OUT" 1>&2
  local PASSED=$(echo "$OUT" | grep -c "$2")
  ((i=3*PASSED))
  echo ${3:i:3}
}

# Notation sur 100.
s2=$(grade "timeout 30 ../../2.sh" "SUCCESS" "  0  0  5 13 18 20")
# IMPORTANT: in 2016, instead of scoring (3.2 + 3.3), we score
# max(3.2, 3.3), and the total points awarded for 3.6 change accordingly.
# When you un-blacklist it, you should also un-comment the old coefficients
# for 3.6 and comment the current ones.
s32=$(grade "timeout 30 ../../3.2.sh" "SUCCESS" "  0  6  6  6  6  6  6  6  6  9 10")
s33=$(grade "timeout 30 ../../3.3.sh" "SUCCESS" "  0 18 30 38 40")
# s36=$(grade "timeout 30 ../../3.6.sh" "SUCCESS" "  0  0  0  0  8  8 14 14 19 19 19 19 19 23 26 28 30")
s36=$(grade "timeout 30 ../../3.6.sh" "SUCCESS" "  0  0  0  0 10 10 18 18 25 25 25 25 25 31 35 38 40")

(( s32 > s33 )) && s33="$s32"
cd ..
rm -rf $TMP
echo "$s2 $s33 $s36"
